==> vdocipher_flutter-2.0.0.tar.gz: lib/src/types/embed_info_options.dart <==
/// Options for video playback.
class EmbedInfoOptions {
  final String? safetyNetApiKey;
  final String? preferredCaptionsLanguage;
  final Duration? startPosition;
  final Duration? endPosition;
  final Duration? resumePosition;
  final int? maxVideoBitrateKbps;
  final int? bufferingGoalMs;
  final List<String>? techOverride;
  final bool disableAnalytics;
  final bool autoplay;
  final bool forceLowestBitrate;
  final bool forceHighestSupportedBitrate;
  final bool allowAdbDebugging;

  const EmbedInfoOptions(
      {this.safetyNetApiKey,
      this.preferredCaptionsLanguage,
      this.startPosition,
      this.endPosition,
      this.resumePosition,
      this.maxVideoBitrateKbps,
      this.bufferingGoalMs,
      this.techOverride,
      this.autoplay = true,
      this.forceLowestBitrate = false,
      this.forceHighestSupportedBitrate = false,
      this.disableAnalytics = false,
      this.allowAdbDebugging = true});

  Map<String, Object?> toMap() {
    return {
      'safetyNetApiKey': safetyNetApiKey,
      'preferredCaptionsLanguage': preferredCaptionsLanguage,
      'startTimeMs':
          startPosition == null ? null : startPosition!.inMilliseconds,
      'endTimeMs': endPosition == null ? null : endPosition!.inMilliseconds,
      'resumeTimeMs':
          resumePosition == null ? null : resumePosition!.inMilliseconds,
      'maxVideoBitrateKbps': maxVideoBitrateKbps,
      'bufferingGoalMs': bufferingGoalMs,
      'techOverride': techOverride,
      'disableAnalytics': disableAnalytics,
      'autoplay': autoplay,
      'forceLowestBitrate': forceLowestBitrate,
      'forceHighestSupportedBitrate': forceHighestSupportedBitrate,
      'allowAdbDebugging': allowAdbDebugging
    };
  }
}

==> vdocipher_flutter-2.2.0.tar.gz: lib/src/types/embed_info_options.dart <==
/// Options for video playback.
class EmbedInfoOptions {
  final String? safetyNetApiKey;
  final String? preferredCaptionsLanguage;
  final Duration? startPosition;
  final Duration? endPosition;
  final Duration? resumePosition;
  final int? maxVideoBitrateKbps;
  final int? bufferingGoalMs;
  final List<Object?>? techOverride;
  final bool disableAnalytics;
  final bool autoplay;
  final bool forceLowestBitrate;
  final bool enablePip;
  final bool forceHighestSupportedBitrate;
  final bool allowAdbDebugging;
  final Map<Object?, Object?>? configMap;
  final String? customPlayerId;

  const EmbedInfoOptions(
      {this.safetyNetApiKey,
      this.preferredCaptionsLanguage,
      this.startPosition,
      this.endPosition,
      this.resumePosition,
      this.maxVideoBitrateKbps,
      this.bufferingGoalMs,
      this.techOverride,
      this.enablePip = false,
      this.autoplay = true,
      this.forceLowestBitrate = false,
      this.forceHighestSupportedBitrate = false,
      this.disableAnalytics = false,
      this.allowAdbDebugging = true,
      this.configMap = null,
      this.customPlayerId = null});

  Map<String, Object?> toMap() {
    return {
      'safetyNetApiKey': safetyNetApiKey,
      'preferredCaptionsLanguage': preferredCaptionsLanguage,
      'startTimeMs':
          startPosition == null ? null : startPosition!.inMilliseconds,
      'endTimeMs': endPosition == null ? null : endPosition!.inMilliseconds,
      'resumeTimeMs':
          resumePosition == null ? null : resumePosition!.inMilliseconds,
      'maxVideoBitrateKbps': maxVideoBitrateKbps,
      'bufferingGoalMs': bufferingGoalMs,
      'techOverride': techOverride,
      'enablePip': enablePip,
      'disableAnalytics': disableAnalytics,
      'autoplay': autoplay,
      'forceLowestBitrate': forceLowestBitrate,
      'forceHighestSupportedBitrate': forceHighestSupportedBitrate,
      'allowAdbDebugging': allowAdbDebugging,
      'configMap': configMap,
      'customPlayerId': customPlayerId,
    };
  }
}
